@@ -238,9 +238,7 @@ def should_backport_by_labels(number, title, labels):
         )
         return False
 
-    force_labels = labels.intersection(
-        ["bug", "force-auto-backport", "force-auto-backport-workflow"]
-    )
+    force_labels = labels.intersection(["bug", "force-auto-backport"])
     if force_labels:
         print(
             f"#{number} '{title}' is labeled as '{list(force_labels)[0]}' which requests automated backporting."
@@ -476,29 +474,7 @@ for index, pr_info in enumerate(
         report_backport_not_done(original_pr, "cherry-pick failed", details)
         continue
 
-    # We don't have the permission to modify workflows
     changed_files = {file.filename for file in original_pr.get_files()}
-    changed_workflow_files = {
-        filename
-        for filename in changed_files
-        if filename.startswith(".github/workflows/")
-    }
-
-    if changed_workflow_files:
-        pull_labels = {label.name for label in original_pr.labels}
-        force_workflow_label = pull_labels.intersection(
-            ["force-auto-backport-workflow"]
-        )
-        if not force_workflow_label:
-            details = (
-                f"The PR touches a workflow file '{list(changed_workflow_files)[0]}' "
-                " and cannot be backported automatically"
-            )
-            report_backport_not_done(original_pr, "backport failed", details)
-            continue
-        print(
-            f"PR #{original_pr.number} '{original_pr.title}' touches a workflow file, but will be backported anyway."
-        )
 
     # Push the backport branch.
     git_check(f"push {source_remote} @:refs/heads/{backport_branch}")
