@@ -47,34 +47,6 @@ static const struct config_enum_entry telemetry_level_options[] = {
 };
 #endif
 
-bool
-ts_is_whitelisted_indexam(const char *amname)
-{
-	ListCell *cell;
-	char *rawname = pstrdup(ts_guc_hypercore_indexam_whitelist);
-
-	List *namelist;
-	if (!SplitIdentifierString(rawname, ',', &namelist))
-	{
-		pfree(rawname);
-		list_free(namelist);
-		elog(ERROR, "List syntax is invalid");
-	}
-	foreach (cell, namelist)
-	{
-		const char *curname = (char *) lfirst(cell);
-		if (strcmp(curname, amname) == 0)
-		{
-			pfree(rawname);
-			list_free(namelist);
-			return true;
-		}
-	}
-	pfree(rawname);
-	list_free(namelist);
-	return false;
-}
-
 /* Copied from contrib/auto_explain/auto_explain.c */
 static const struct config_enum_entry loglevel_options[] = {
 	{ "debug5", DEBUG5, false }, { "debug4", DEBUG4, false }, { "debug3", DEBUG3, false },
@@ -84,40 +56,6 @@ static const struct config_enum_entry loglevel_options[] = {
 	{ NULL, 0, false }
 };
 
-/*
- * Setting to enable or disable transparent decompression plans.
- *
- * The setting is an integer instead of boolean because it is possible to
- * enable transparent decompression plans also when using the Hypercore table
- * access method. But this is not enabled by default. The options are as
- * follows:
- *
- * (0) = off, disabled completely.
- *
- * (1) = on, enabled for compressed tables but not tables using Hypercore
- *       TAM. This is the default setting.
- *
- * (2) = hypercore, enabled for compressed tables and those using Hypercore
- *       TAM. This is useful mostly for debugging/testing and as a fallback.
- *       Only available in debug builds.
- */
-static const struct config_enum_entry transparent_decompression_options[] = {
-	{ "on", 1, false },
-	{ "true", 1, false },
-	{ "off", 0, false },
-	{ "false", 0, false },
-#ifdef TS_DEBUG
-	{ TS_HYPERCORE_TAM_NAME, 2, false },
-#endif
-	{ NULL, 0, false }
-};
-
-static const struct config_enum_entry hypercore_copy_to_options[] = {
-	{ "all_data", HYPERCORE_COPY_ALL_DATA, false },
-	{ "no_compressed_data", HYPERCORE_COPY_NO_COMPRESSED_DATA, false },
-	{ NULL, 0, false }
-};
-
 static const struct config_enum_entry compress_truncate_behaviour_options[] = {
 	{ "truncate_only", COMPRESS_TRUNCATE_ONLY, false },
 	{ "truncate_or_delete", COMPRESS_TRUNCATE_OR_DELETE, false },
@@ -125,9 +63,17 @@ static const struct config_enum_entry compress_truncate_behaviour_options[] = {
 	{ NULL, 0, false }
 };
 
+#define GUC_CAGG_LOW_WORK_MEM_NAME "cagg_processing_low_work_mem"
+#define GUC_CAGG_LOW_WORK_MEM_VALUE (0.6 * 65536)
+#define GUC_CAGG_HIGH_WORK_MEM_NAME "cagg_processing_high_work_mem"
+#define GUC_CAGG_HIGH_WORK_MEM_VALUE (0.8 * 65536)
+
 bool ts_guc_enable_direct_compress_copy = false;
 bool ts_guc_enable_direct_compress_copy_sort_batches = true;
 bool ts_guc_enable_direct_compress_copy_client_sorted = false;
+bool ts_guc_enable_direct_compress_insert = false;
+bool ts_guc_enable_direct_compress_insert_sort_batches = true;
+bool ts_guc_enable_direct_compress_insert_client_sorted = false;
 bool ts_guc_enable_deprecation_warnings = true;
 bool ts_guc_enable_optimizations = true;
 bool ts_guc_restoring = false;
@@ -147,12 +93,16 @@ TSDLLEXPORT bool ts_guc_enable_cagg_sort_pushdown = true;
 #endif
 TSDLLEXPORT bool ts_guc_enable_cagg_watermark_constify = true;
 TSDLLEXPORT int ts_guc_cagg_max_individual_materializations = 10;
+TSDLLEXPORT bool ts_guc_enable_cagg_wal_based_invalidation = false;
+TSDLLEXPORT int ts_guc_cagg_wal_batch_size = 10000;
+TSDLLEXPORT int ts_guc_cagg_low_work_mem = GUC_CAGG_LOW_WORK_MEM_VALUE;
+TSDLLEXPORT int ts_guc_cagg_high_work_mem = GUC_CAGG_HIGH_WORK_MEM_VALUE;
 bool ts_guc_enable_osm_reads = true;
 TSDLLEXPORT bool ts_guc_enable_compressed_direct_batch_delete = true;
 TSDLLEXPORT bool ts_guc_enable_dml_decompression = true;
 TSDLLEXPORT bool ts_guc_enable_dml_decompression_tuple_filtering = true;
 TSDLLEXPORT int ts_guc_max_tuples_decompressed_per_dml = 100000;
-TSDLLEXPORT int ts_guc_enable_transparent_decompression = 1;
+TSDLLEXPORT bool ts_guc_enable_transparent_decompression = true;
 TSDLLEXPORT bool ts_guc_enable_compression_wal_markers = false;
 TSDLLEXPORT bool ts_guc_enable_decompression_sorted_merge = true;
 bool ts_guc_enable_chunkwise_aggregation = true;
@@ -162,15 +112,16 @@ TSDLLEXPORT bool ts_guc_enable_compression_indexscan = false;
 TSDLLEXPORT bool ts_guc_enable_bulk_decompression = true;
 TSDLLEXPORT bool ts_guc_auto_sparse_indexes = true;
 TSDLLEXPORT bool ts_guc_enable_sparse_index_bloom = true;
-TSDLLEXPORT bool ts_guc_default_hypercore_use_access_method = false;
 bool ts_guc_enable_chunk_skipping = false;
 TSDLLEXPORT bool ts_guc_enable_segmentwise_recompression = true;
 TSDLLEXPORT bool ts_guc_enable_exclusive_locking_recompression = false;
 TSDLLEXPORT bool ts_guc_enable_bool_compression = true;
+TSDLLEXPORT bool ts_guc_enable_uuid_compression = true;
 TSDLLEXPORT int ts_guc_compression_batch_size_limit = 1000;
 TSDLLEXPORT bool ts_guc_compression_enable_compressor_batch_limit = false;
 TSDLLEXPORT CompressTruncateBehaviour ts_guc_compress_truncate_behaviour = COMPRESS_TRUNCATE_ONLY;
 bool ts_guc_enable_event_triggers = false;
+bool ts_guc_debug_skip_scan_info = false;
 
 /* Only settable in debug mode for testing */
 TSDLLEXPORT bool ts_guc_enable_null_compression = true;
@@ -185,6 +136,7 @@ TSDLLEXPORT bool ts_guc_enable_skip_scan = true;
 TSDLLEXPORT bool ts_guc_enable_skip_scan_for_distinct_aggregates = true;
 #endif
 TSDLLEXPORT bool ts_guc_enable_compressed_skip_scan = true;
+TSDLLEXPORT bool ts_guc_enable_multikey_skip_scan = true;
 TSDLLEXPORT double ts_guc_skip_scan_run_cost_multiplier = 1.0;
 static char *ts_guc_default_segmentby_fn = NULL;
 static char *ts_guc_default_orderby_fn = NULL;
@@ -192,11 +144,6 @@ TSDLLEXPORT bool ts_guc_enable_job_execution_logging = false;
 bool ts_guc_enable_tss_callbacks = true;
 TSDLLEXPORT bool ts_guc_enable_delete_after_compression = false;
 TSDLLEXPORT bool ts_guc_enable_merge_on_cagg_refresh = false;
-TSDLLEXPORT char *ts_guc_hypercore_indexam_whitelist;
-TSDLLEXPORT HypercoreCopyToBehavior ts_guc_hypercore_copy_to_behavior =
-	HYPERCORE_COPY_NO_COMPRESSED_DATA;
-TSDLLEXPORT bool ts_guc_enable_hypercore_scankey_pushdown = true;
-TSDLLEXPORT int ts_guc_hypercore_arrow_cache_max_entries;
 
 /* default value of ts_guc_max_open_chunks_per_insert and
  * ts_guc_max_cached_chunks_per_hypertable will be set as their respective boot-value when the
@@ -212,8 +159,6 @@ TSDLLEXPORT char *ts_guc_license = TS_LICENSE_DEFAULT;
 char *ts_last_tune_time = NULL;
 char *ts_last_tune_version = NULL;
 
-bool ts_guc_debug_require_batch_sorted_merge = false;
-
 bool ts_guc_debug_allow_cagg_with_deprecated_funcs = false;
 
 /*
@@ -237,20 +182,23 @@ char *ts_current_timestamp_mock = NULL;
 
 int ts_guc_debug_toast_tuple_target = 128;
 
-#ifdef TS_DEBUG
-
-bool ts_guc_debug_have_int128;
-
 static const struct config_enum_entry debug_require_options[] = { { "allow", DRO_Allow, false },
 																  { "forbid", DRO_Forbid, false },
 																  { "require", DRO_Require, false },
+																  { "force", DRO_Force, false },
 																  { NULL, 0, false } };
 
+#ifdef TS_DEBUG
+
+bool ts_guc_debug_have_int128;
+
 DebugRequireOption ts_guc_debug_require_vector_qual = DRO_Allow;
 
 DebugRequireOption ts_guc_debug_require_vector_agg = DRO_Allow;
 #endif
 
+DebugRequireOption ts_guc_debug_require_batch_sorted_merge = false;
+
 bool ts_guc_debug_compression_path_info = false;
 bool ts_guc_enable_rowlevel_compression_locking = false;
 
@@ -383,30 +331,34 @@ get_segmentby_func(char *input_name)
 }
 
 static bool
-check_indexam_whitelist(char **newval, void **extra, GucSource source)
+check_cagg_low_work_mem(int *newval, void **extra, GucSource source)
 {
-	char *rawname;
-	List *namelist;
-
-	/* Need a modifiable copy of string */
-	rawname = pstrdup(*newval);
-
-	/* Parse string into list of identifiers */
-	if (!SplitIdentifierString(rawname, ',', &namelist))
+	if (*newval >= ts_guc_cagg_high_work_mem)
 	{
-		/* syntax error in name list */
-		GUC_check_errdetail("List syntax is invalid.");
-		pfree(rawname);
-		list_free(namelist);
+		GUC_check_errdetail("\"%s\" must be less than value of \"%s\".",
+							GUC_CAGG_LOW_WORK_MEM_NAME,
+							GUC_CAGG_HIGH_WORK_MEM_NAME);
+		GUC_check_errhint("Set \"%s\" to a value less than %d.",
+						  GUC_CAGG_LOW_WORK_MEM_NAME,
+						  ts_guc_cagg_high_work_mem);
 		return false;
 	}
+	return true;
+}
 
-	/* We might not be in a transaction when setting this so cannot consult
-	 * the systems catalog. We just require the list of index access methods
-	 * to be syntactically correct. */
-
-	pfree(rawname);
-	list_free(namelist);
+static bool
+check_cagg_high_work_mem(int *newval, void **extra, GucSource source)
+{
+	if (*newval <= ts_guc_cagg_low_work_mem)
+	{
+		GUC_check_errdetail("\"%s\" must be greater than value of \"%s\".",
+							GUC_CAGG_HIGH_WORK_MEM_NAME,
+							GUC_CAGG_LOW_WORK_MEM_NAME);
+		GUC_check_errhint("Set \"%s\" to a value greater than %d.",
+						  GUC_CAGG_HIGH_WORK_MEM_NAME,
+						  ts_guc_cagg_low_work_mem);
+		return false;
+	}
 	return true;
 }
 
@@ -523,6 +475,40 @@ _guc_init(void)
 							 NULL,
 							 NULL);
 
+	DefineCustomBoolVariable(MAKE_EXTOPTION("enable_direct_compress_insert"),
+							 "Enable direct compression during INSERT",
+							 "Enable experimental support for direct compression during INSERT",
+							 &ts_guc_enable_direct_compress_insert,
+							 false,
+							 PGC_USERSET,
+							 0,
+							 NULL,
+							 NULL,
+							 NULL);
+
+	DefineCustomBoolVariable(MAKE_EXTOPTION("enable_direct_compress_insert_sort_batches"),
+							 "Enable batch sorting during direct compress INSERT",
+							 NULL,
+							 &ts_guc_enable_direct_compress_insert_sort_batches,
+							 true,
+							 PGC_USERSET,
+							 0,
+							 NULL,
+							 NULL,
+							 NULL);
+
+	DefineCustomBoolVariable(MAKE_EXTOPTION("enable_direct_compress_insert_client_sorted"),
+							 "Enable direct compress INSERT with presorted data",
+							 "Correct handling of data sorting by the user is required for this "
+							 "option.",
+							 &ts_guc_enable_direct_compress_insert_client_sorted,
+							 false,
+							 PGC_USERSET,
+							 0,
+							 NULL,
+							 NULL,
+							 NULL);
+
 	DefineCustomBoolVariable(MAKE_EXTOPTION("enable_optimizations"),
 							 "Enable TimescaleDB query optimizations",
 							 NULL,
@@ -687,12 +673,11 @@ _guc_init(void)
 							NULL,
 							NULL);
 
-	DefineCustomEnumVariable(MAKE_EXTOPTION("enable_transparent_decompression"),
+	DefineCustomBoolVariable(MAKE_EXTOPTION("enable_transparent_decompression"),
 							 "Enable transparent decompression",
 							 "Enable transparent decompression when querying hypertable",
 							 &ts_guc_enable_transparent_decompression,
-							 1,
-							 transparent_decompression_options,
+							 true,
 							 PGC_USERSET,
 							 0,
 							 NULL,
@@ -733,6 +718,17 @@ _guc_init(void)
 							 NULL,
 							 NULL);
 
+	DefineCustomBoolVariable(MAKE_EXTOPTION("enable_multikey_skipscan"),
+							 "Enable SkipScan for multiple distinct keys",
+							 "Enable SkipScan for multiple distinct inputs",
+							 &ts_guc_enable_multikey_skip_scan,
+							 true,
+							 PGC_USERSET,
+							 0,
+							 NULL,
+							 NULL,
+							 NULL);
+
 	DefineCustomRealVariable(MAKE_EXTOPTION("skip_scan_run_cost_multiplier"),
 							 "Multiplier for SkipScan run cost as an option to make the cost "
 							 "smaller so that SkipScan can be chosen",
@@ -748,6 +744,17 @@ _guc_init(void)
 							 NULL,
 							 NULL);
 
+	DefineCustomBoolVariable(MAKE_EXTOPTION("debug_skip_scan_info"),
+							 "Print debug info about SkipScan",
+							 "Print debug info about SkipScan distinct columns",
+							 &ts_guc_debug_skip_scan_info,
+							 false,
+							 PGC_USERSET,
+							 0,
+							 NULL,
+							 NULL,
+							 NULL);
+
 	DefineCustomBoolVariable(MAKE_EXTOPTION("enable_compression_wal_markers"),
 							 "Enable WAL markers for compression ops",
 							 "Enable the generation of markers in the WAL stream which mark the "
@@ -885,6 +892,17 @@ _guc_init(void)
 							 NULL,
 							 NULL);
 
+	DefineCustomBoolVariable(MAKE_EXTOPTION("enable_uuid_compression"),
+							 "Enable uuid compression functionality",
+							 "Enable uuid compression",
+							 &ts_guc_enable_uuid_compression,
+							 true,
+							 PGC_USERSET,
+							 0,
+							 NULL,
+							 NULL,
+							 NULL);
+
 	DefineCustomIntVariable(MAKE_EXTOPTION("compression_batch_size_limit"),
 							"The max number of tuples that can be batched together during "
 							"compression",
@@ -949,26 +967,64 @@ _guc_init(void)
 							 NULL,
 							 NULL,
 							 NULL);
-	/*
-	 * Define the limit on number of invalidation-based refreshes we allow per
-	 * refresh call. If this limit is exceeded, fall back to a single refresh that
-	 * covers the range decided by the min and max invalidated time.
-	 */
-	DefineCustomIntVariable(MAKE_EXTOPTION("materializations_per_refresh_window"),
-							"Max number of materializations per cagg refresh window",
-							"The maximal number of individual refreshes per cagg refresh. If more "
-							"refreshes need to be performed, they are merged into a larger "
-							"single refresh.",
-							&ts_guc_cagg_max_individual_materializations,
-							10,
-							0,
-							INT_MAX,
+
+	DefineCustomBoolVariable(MAKE_EXTOPTION("enable_cagg_wal_based_invalidation"),
+							 "Enable experimental invalidations for continuous aggregates using "
+							 "WAL",
+							 "Use WAL to track changes to hypertables for continuous aggregates. "
+							 "This is not meant for production use.",
+							 &ts_guc_enable_cagg_wal_based_invalidation,
+							 false,
+							 PGC_USERSET,
+							 0,
+							 NULL,
+							 NULL,
+							 NULL);
+
+	DefineCustomIntVariable(MAKE_EXTOPTION("cagg_processing_wal_batch_size"),
+							"Batch size when processing WAL entries.",
+							"Number of entries processed from the WAL at a go. Larger values take "
+							"more memory but might be more efficient.",
+							&ts_guc_cagg_wal_batch_size,
+							10000,
+							1000,
+							10000000,
 							PGC_USERSET,
 							0,
 							NULL,
 							NULL,
 							NULL);
 
+	DefineCustomIntVariable(MAKE_EXTOPTION(GUC_CAGG_LOW_WORK_MEM_NAME),
+							"Low working memory limit for continuous aggregate invalidation "
+							"processing.",
+							"The low working memory limit for the continuous aggregate "
+							"invalidation processing.",
+							&ts_guc_cagg_low_work_mem,
+							GUC_CAGG_LOW_WORK_MEM_VALUE,
+							64,
+							MAX_KILOBYTES,
+							PGC_USERSET,
+							GUC_UNIT_KB,
+							check_cagg_low_work_mem,
+							NULL,
+							NULL);
+
+	DefineCustomIntVariable(MAKE_EXTOPTION(GUC_CAGG_HIGH_WORK_MEM_NAME),
+							"High working memory limit for continuous aggregate invalidation "
+							"processing.",
+							"The high working memory limit for the continuous aggregate "
+							"invalidation processing.",
+							&ts_guc_cagg_high_work_mem,
+							GUC_CAGG_HIGH_WORK_MEM_VALUE,
+							64,
+							MAX_KILOBYTES,
+							PGC_USERSET,
+							GUC_UNIT_KB,
+							check_cagg_high_work_mem,
+							NULL,
+							NULL);
+
 	DefineCustomBoolVariable(MAKE_EXTOPTION("enable_tiered_reads"),
 							 "Enable tiered data reads",
 							 "Enable reading of tiered data by including a foreign table "
@@ -1273,64 +1329,6 @@ _guc_init(void)
 							   /* show_hook= */ NULL);
 #endif
 
-	DefineCustomStringVariable(MAKE_EXTOPTION("hypercore_indexam_whitelist"),
-							   gettext_noop(
-								   "Whitelist for index access methods supported by hypercore."),
-							   gettext_noop(
-								   "List of index access method names supported by hypercore."),
-							   /* valueAddr= */ &ts_guc_hypercore_indexam_whitelist,
-							   /* Value= */ "btree,hash",
-							   /* context= */ PGC_SIGHUP,
-							   /* flags= */ GUC_LIST_INPUT | GUC_SUPERUSER_ONLY,
-							   /* check_hook= */ check_indexam_whitelist,
-							   /* assign_hook= */ NULL,
-							   /* show_hook= */ NULL);
-
-	DefineCustomEnumVariable(MAKE_EXTOPTION("hypercore_copy_to_behavior"),
-							 "The behavior of COPY TO on a hypercore table",
-							 "Set to 'all_data' to return both compressed and uncompressed data "
-							 "via the Hypercore table when using COPY TO. Set to "
-							 "'no_compressed_data' to skip compressed data.",
-							 /* valueAddr= */ (int *) &ts_guc_hypercore_copy_to_behavior,
-							 /* bootValue= */ HYPERCORE_COPY_NO_COMPRESSED_DATA,
-							 /* options= */ hypercore_copy_to_options,
-							 /* context= */ PGC_USERSET,
-							 0,
-							 NULL,
-							 NULL,
-							 NULL);
-
-	DefineCustomBoolVariable(/* name= */ MAKE_EXTOPTION("enable_hypercore_scankey_pushdown"),
-							 /* short_desc= */
-							 "Push down qualifiers as scankeys when using Hypercore TAM",
-							 /* long_desc= */
-							 "Enabling this setting might lead to faster scans when "
-							 "query qualifiers match Hypercore segmentby and orderby columns.",
-							 /* valueAddr= */ &ts_guc_enable_hypercore_scankey_pushdown,
-							 /* bootValue= */ true,
-							 /* context= */ PGC_USERSET,
-							 /* flags= */ 0,
-							 /* check_hook= */ NULL,
-							 /* assign_hook= */ NULL,
-							 /* show_hook= */ NULL);
-
-	DefineCustomIntVariable(/* name= */ MAKE_EXTOPTION("hypercore_arrow_cache_max_entries"),
-							/* short_desc= */ "max number of entries in arrow data cache",
-							/* long_desc= */
-							"The max number of decompressed arrow segments that can be "
-							"cached before entries are evicted. This mainly affects the "
-							"performance of index scans on the Hypercore TAM "
-							"when segments are accessed in non-sequential order.",
-							/* valueAddr= */ &ts_guc_hypercore_arrow_cache_max_entries,
-							/* bootValue= */ 25000,
-							/* minValue= */ 1,
-							/* maxValue= */ INT_MAX,
-							/* context= */ PGC_USERSET,
-							/* flags= */ 0,
-							/* check_hook= */ NULL,
-							/* assign_hook= */ NULL,
-							/* show_hook= */ NULL);
-
 	DefineCustomIntVariable(/* name= */ MAKE_EXTOPTION("debug_bgw_scheduler_exit_status"),
 							/* short_desc= */ "exit status to use when shutting down the scheduler",
 							/* long_desc= */ "this is for debugging purposes",
@@ -1344,6 +1342,18 @@ _guc_init(void)
 							/* assign_hook= */ NULL,
 							/* show_hook= */ NULL);
 
+	DefineCustomEnumVariable(/* name= */ MAKE_EXTOPTION("debug_require_batch_sorted_merge"),
+							 /* short_desc= */ "require batch sorted merge in ColumnarScan node",
+							 /* long_desc= */ "this is for debugging purposes",
+							 /* valueAddr= */ (int *) &ts_guc_debug_require_batch_sorted_merge,
+							 /* bootValue= */ DRO_Allow,
+							 /* options = */ debug_require_options,
+							 /* context= */ PGC_USERSET,
+							 /* flags= */ 0,
+							 /* check_hook= */ NULL,
+							 /* assign_hook= */ NULL,
+							 /* show_hook= */ NULL);
+
 #ifdef TS_DEBUG
 	DefineCustomBoolVariable(/* name= */ MAKE_EXTOPTION("shutdown_bgw_scheduler"),
 							 /* short_desc= */ "immediately shutdown the bgw scheduler",
@@ -1411,7 +1421,7 @@ _guc_init(void)
 	DefineCustomEnumVariable(/* name= */ MAKE_EXTOPTION("debug_require_vector_qual"),
 							 /* short_desc= */
 							 "ensure that non-vectorized or vectorized filters are used in "
-							 "DecompressChunk node",
+							 "ColumnarScan node",
 							 /* long_desc= */
 							 "this is for debugging purposes, to let us check if the vectorized "
 							 "quals are used or not. EXPLAIN differs after PG15 for custom nodes, "
@@ -1426,17 +1436,6 @@ _guc_init(void)
 							 /* assign_hook= */ NULL,
 							 /* show_hook= */ NULL);
 
-	DefineCustomBoolVariable(/* name= */ MAKE_EXTOPTION("debug_require_batch_sorted_merge"),
-							 /* short_desc= */ "require batch sorted merge in DecompressChunk node",
-							 /* long_desc= */ "this is for debugging purposes",
-							 /* valueAddr= */ &ts_guc_debug_require_batch_sorted_merge,
-							 /* bootValue= */ false,
-							 /* context= */ PGC_USERSET,
-							 /* flags= */ 0,
-							 /* check_hook= */ NULL,
-							 /* assign_hook= */ NULL,
-							 /* show_hook= */ NULL);
-
 	DefineCustomBoolVariable(/* name= */ MAKE_EXTOPTION("debug_allow_cagg_with_deprecated_funcs"),
 							 /* short_desc= */ "allow new caggs using time_bucket_ng",
 							 /* long_desc= */ "this is for debugging/testing purposes",
@@ -1449,18 +1448,6 @@ _guc_init(void)
 							 /* show_hook= */ NULL);
 #endif
 
-	DefineCustomBoolVariable(MAKE_EXTOPTION("default_hypercore_use_access_method"),
-							 gettext_noop("Enable to always use Hypercore TAM when compressing."),
-							 gettext_noop("Sets the global default for using Hypercore TAM when "
-										  "compressing chunks."),
-							 &ts_guc_default_hypercore_use_access_method,
-							 false,
-							 /* context= */ PGC_USERSET,
-							 /* flags= */ 0,
-							 /* check_hook= */ NULL,
-							 /* assign_hook= */ NULL,
-							 /* show_hook= */ NULL);
-
 	/* register feature flags */
 	ts_feature_flag_add(FEATURE_HYPERTABLE);
 	ts_feature_flag_add(FEATURE_HYPERTABLE_COMPRESSION);
