@@ -6,6 +6,7 @@
 
 #include "common.h"
 
+#include <utils/acl.h>
 #include <utils/date.h>
 #include <utils/timestamp.h>
 
@@ -573,10 +574,10 @@ cagg_query_supported(const Query *query, StringInfo hint, StringInfo detail, con
 		return false;
 	}
 
-	if (query->hasRecursive || query->hasSubLinks || query->hasTargetSRFs || query->cteList)
+	if (query->hasRecursive || query->hasSubLinks || query->cteList)
 	{
 		appendStringInfoString(detail,
-							   "CTEs, subqueries and set-returning functions are not supported by "
+							   "CTEs and subqueries are not supported by "
 							   "continuous aggregates.");
 		return false;
 	}
@@ -838,6 +839,23 @@ cagg_validate_query(const Query *query, const bool finalized, const char *cagg_s
 		prev_query = ts_continuous_agg_get_query(cagg_parent);
 	}
 
+	/*
+	 * Check if user can refresh continuous aggregate
+	 * We only check for SELECT on the hypertable here but there
+	 * could be other permissions needed depending on the query.
+	 * For WITH DATA this is not a problem since we try a refresh
+	 * immediately but for WITH NO DATA the refresh might still
+	 * fail due to other permissions being needed.
+	 */
+	AclResult aclresult = pg_class_aclcheck(ht->main_table_relid, GetUserId(), ACL_SELECT);
+	if (aclresult != ACLCHECK_OK)
+	{
+		/* User doesn't have permission */
+		aclcheck_error(aclresult,
+					   get_relkind_objtype(get_rel_relkind(ht->main_table_relid)),
+					   get_rel_name(ht->main_table_relid));
+	}
+
 	if (TS_HYPERTABLE_IS_INTERNAL_COMPRESSION_TABLE(ht))
 	{
 		ts_cache_release(&hcache);
