@@ -26,6 +26,6 @@
 extern Query *finalize_query_get_select_query(FinalizeQueryInfo *inp, List *matcollist,
 											  ObjectAddress *mattbladdress);
 extern void finalizequery_init(FinalizeQueryInfo *inp, Query *orig_query,
-							   MatTableColumnInfo *mattblinfo);
+							   MaterializationHypertableColumnInfo *mattblinfo);
 extern Query *finalizequery_get_select_query(FinalizeQueryInfo *inp, List *matcollist,
 											 ObjectAddress *mattbladdress, char *relname);
