@@ -19,10 +19,10 @@
 
 #include "compat/compat.h"
 #include "compression/arrow_c_data_interface.h"
-#include "nodes/decompress_chunk/compressed_batch.h"
-#include "nodes/decompress_chunk/decompress_chunk.h"
-#include "nodes/decompress_chunk/exec.h"
-#include "nodes/decompress_chunk/vector_quals.h"
+#include "nodes/columnar_scan/columnar_scan.h"
+#include "nodes/columnar_scan/compressed_batch.h"
+#include "nodes/columnar_scan/exec.h"
+#include "nodes/columnar_scan/vector_quals.h"
 #include "nodes/vector_agg.h"
 #include "nodes/vector_agg/plan.h"
 
@@ -32,7 +32,7 @@
 #endif
 
 static int
-get_input_offset(const DecompressChunkState *decompress_state, const Var *var)
+get_input_offset(const ColumnarScanState *decompress_state, const Var *var)
 {
 	const DecompressContext *dcontext = &decompress_state->decompress_context;
 
@@ -66,7 +66,7 @@ get_input_offset(const DecompressChunkState *decompress_state, const Var *var)
 }
 
 static void
-get_column_storage_properties(const DecompressChunkState *state, int input_offset,
+get_column_storage_properties(const ColumnarScanState *state, int input_offset,
 							  GroupingColumn *result)
 {
 	const DecompressContext *dcontext = &state->decompress_context;
@@ -173,8 +173,7 @@ vector_agg_begin(CustomScanState *node, EState *estate, int eflags)
 				Assert(aggref->aggsplit == AGGSPLIT_INITIAL_SERIAL);
 
 				Var *var = castNode(Var, castNode(TargetEntry, linitial(aggref->args))->expr);
-				def->input_offset =
-					get_input_offset((const DecompressChunkState *) childstate, var);
+				def->input_offset = get_input_offset((const ColumnarScanState *) childstate, var);
 			}
 			else
 			{
@@ -196,8 +195,8 @@ vector_agg_begin(CustomScanState *node, EState *estate, int eflags)
 			col->output_offset = i;
 
 			Var *var = castNode(Var, tlentry->expr);
-			col->input_offset = get_input_offset((const DecompressChunkState *) childstate, var);
-			get_column_storage_properties((const DecompressChunkState *) childstate,
+			col->input_offset = get_input_offset((const ColumnarScanState *) childstate, var);
+			get_column_storage_properties((const ColumnarScanState *) childstate,
 										  col->input_offset,
 										  col);
 		}
@@ -256,9 +255,9 @@ vector_agg_rescan(CustomScanState *node)
 /*
  * Get the next slot to aggregate for a compressed batch.
  *
- * Implements "get next slot" on top of DecompressChunk. Note that compressed
- * tuples are read directly from the DecompressChunk child node, which means
- * that the processing normally done in DecompressChunk is actually done here
+ * Implements "get next slot" on top of ColumnarScan. Note that compressed
+ * tuples are read directly from the ColumnarScan child node, which means
+ * that the processing normally done in ColumnarScan is actually done here
  * (batch processing and filtering).
  *
  * Returns an TupleTableSlot that implements a compressed batch.
@@ -266,8 +265,8 @@ vector_agg_rescan(CustomScanState *node)
 static TupleTableSlot *
 compressed_batch_get_next_slot(VectorAggState *vector_agg_state)
 {
-	DecompressChunkState *decompress_state =
-		(DecompressChunkState *) linitial(vector_agg_state->custom.custom_ps);
+	ColumnarScanState *decompress_state =
+		(ColumnarScanState *) linitial(vector_agg_state->custom.custom_ps);
 	DecompressContext *dcontext = &decompress_state->decompress_context;
 	BatchQueue *batch_queue = decompress_state->batch_queue;
 	DecompressBatchState *batch_state = batch_array_get_at(&batch_queue->batch_array, 0);
@@ -295,13 +294,13 @@ compressed_batch_get_next_slot(VectorAggState *vector_agg_state)
 		if (dcontext->ps->instrument)
 		{
 			/*
-			 * Ensure proper EXPLAIN output for the underlying DecompressChunk
+			 * Ensure proper EXPLAIN output for the underlying ColumnarScan
 			 * node.
 			 *
 			 * This value is normally updated by InstrStopNode(), and is
 			 * required so that the calculations in InstrEndLoop() run properly.
 			 * We have to call it manually because we run the underlying
-			 * DecompressChunk manually and not as a normal Postgres node.
+			 * ColumnarScan manually and not as a normal Postgres node.
 			 */
 			dcontext->ps->instrument->running = true;
 		}
@@ -314,7 +313,7 @@ compressed_batch_get_next_slot(VectorAggState *vector_agg_state)
 
 	/*
 	 * Count rows filtered out by vectorized filters for EXPLAIN. Normally
-	 * this is done in tuple-by-tuple interface of DecompressChunk, so that
+	 * this is done in tuple-by-tuple interface of ColumnarScan, so that
 	 * it doesn't say it filtered out more rows that were returned (e.g.
 	 * with LIMIT). Here we always work in full batches. The batches that
 	 * were fully filtered out, and their rows, were already counted in
@@ -326,13 +325,13 @@ compressed_batch_get_next_slot(VectorAggState *vector_agg_state)
 	if (dcontext->ps->instrument)
 	{
 		/*
-		 * Ensure proper EXPLAIN output for the underlying DecompressChunk
+		 * Ensure proper EXPLAIN output for the underlying ColumnarScan
 		 * node.
 		 *
 		 * This value is normally updated by InstrStopNode(), and is
 		 * required so that the calculations in InstrEndLoop() run properly.
 		 * We have to call it manually because we run the underlying
-		 * DecompressChunk manually and not as a normal Postgres node.
+		 * ColumnarScan manually and not as a normal Postgres node.
 		 */
 		dcontext->ps->instrument->tuplecount += not_filtered_rows;
 	}
@@ -349,8 +348,8 @@ static VectorQualState *
 compressed_batch_init_vector_quals(VectorAggState *agg_state, VectorAggDef *agg_def,
 								   TupleTableSlot *slot)
 {
-	DecompressChunkState *decompress_state =
-		(DecompressChunkState *) linitial(agg_state->custom.custom_ps);
+	ColumnarScanState *decompress_state =
+		(ColumnarScanState *) linitial(agg_state->custom.custom_ps);
 	DecompressContext *dcontext = &decompress_state->decompress_context;
 	DecompressBatchState *batch_state = (DecompressBatchState *) slot;
 
@@ -509,7 +508,7 @@ Node *
 vector_agg_state_create(CustomScan *cscan)
 {
 	VectorAggState *state = (VectorAggState *) newNode(sizeof(VectorAggState), T_CustomScanState);
-	Assert(ts_is_decompress_chunk_plan((Plan *) linitial(cscan->custom_plans)));
+	Assert(ts_is_columnar_scan_plan((Plan *) linitial(cscan->custom_plans)));
 
 	state->custom.methods = &exec_methods;
 
@@ -517,8 +516,8 @@ vector_agg_state_create(CustomScan *cscan)
 	 * Initialize VectorAggState to process vector slots from different
 	 * subnodes.
 	 *
-	 * When the child is DecompressChunk, VectorAgg doesn't read the slot from
-	 * the child node. Instead, it bypasses DecompressChunk and reads
+	 * When the child is ColumnarScan, VectorAgg doesn't read the slot from
+	 * the child node. Instead, it bypasses ColumnarScan and reads
 	 * compressed tuples directly from the grandchild. It therefore needs to
 	 * handle batch decompression and vectorized qual filtering itself, in its
 	 * own "get next slot" implementation.
