@@ -639,8 +639,25 @@ FROM mat_m1
 GROUP BY 1
 WITH NO DATA;
 
-SELECT add_continuous_aggregate_policy('mat_m1_rollup', NULL, '30 days'::interval, '12 h'::interval);
+CREATE MATERIALIZED VIEW mat_m1_rollup2
+WITH (timescaledb.continuous, timescaledb.materialized_only=true)
+AS
+SELECT
+    time_bucket('1 month', bucket) AS bucket,
+    sum(counta) AS counta,
+    sum(sumb) AS sumb
+FROM mat_m1
+GROUP BY 1
+WITH NO DATA;
+
+SELECT add_continuous_aggregate_policy('mat_m1_rollup', NULL, '30 days'::interval, '12 h'::interval) AS "JOB_ID" \gset
+-- alter_job should not be blocked
+SELECT alter_job(:JOB_ID, next_start => '2000-01-01'::timestamptz);
 \set ON_ERROR_STOP 0
 -- Multiple policies on hierarchical cagg should not be allowed
 SELECT add_continuous_aggregate_policy('mat_m1_rollup', '29 days'::interval, NULL, '12 h'::interval);
 \set ON_ERROR_STOP 1
+-- different hierarchical caggs should be allowed to have their own policies
+SELECT add_continuous_aggregate_policy('mat_m1_rollup2', NULL, '30 days'::interval, '12 h'::interval) AS "JOB_ID2" \gset
+SELECT alter_job(:JOB_ID2, next_start => '2000-01-01'::timestamptz);
+
