@@ -12,26 +12,26 @@ alter table sparse set (timescaledb.compress, timescaledb.order_by='ts desc');
 create index ii on sparse(value);
 select count(compress_chunk(x)) from show_chunks('sparse') x;
 vacuum analyze sparse;
-explain (costs off) select * from sparse where value = 1;
+explain (buffers off, costs off) select * from sparse where value = 1;
 
 
 -- Should be disabled with the GUC
 set timescaledb.auto_sparse_indexes to off;
 select count(compress_chunk(decompress_chunk(x))) from show_chunks('sparse') x;
 vacuum analyze sparse;
-explain (costs off) select * from sparse where value = 1;
+explain (buffers off, costs off) select * from sparse where value = 1;
 
 reset timescaledb.auto_sparse_indexes;
 select count(compress_chunk(decompress_chunk(x))) from show_chunks('sparse') x;
 vacuum analyze sparse;
-explain (costs off) select * from sparse where value = 1;
+explain (buffers off, costs off) select * from sparse where value = 1;
 
 
 -- Should survive renames.
 alter table sparse rename column value to wert;
-explain (costs off) select * from sparse where wert = 1;
+explain (buffers off, costs off) select * from sparse where wert = 1;
 alter table sparse rename column wert to value;
-explain (costs off) select * from sparse where value = 1;
+explain (buffers off, costs off) select * from sparse where value = 1;
 
 
 -- Not for expression indexes.
@@ -39,7 +39,7 @@ drop index ii;
 create index ii on sparse((value + 1));
 select count(compress_chunk(decompress_chunk(x))) from show_chunks('sparse') x;
 vacuum analyze sparse;
-explain (costs off) select * from sparse where value = 1;
+explain (buffers off, costs off) select * from sparse where value = 1;
 
 
 -- Not for other index types.
@@ -47,14 +47,14 @@ drop index ii;
 create index ii on sparse using hash(value);
 select count(compress_chunk(decompress_chunk(x))) from show_chunks('sparse') x;
 vacuum analyze sparse;
-explain (costs off) select * from sparse where value = 1;
+explain (buffers off, costs off) select * from sparse where value = 1;
 
 
 -- When the chunk is recompressed without index, no sparse index is created.
 drop index ii;
 select count(compress_chunk(decompress_chunk(x))) from show_chunks('sparse') x;
 vacuum analyze sparse;
-explain (costs off) select * from sparse where value = 1;
+explain (buffers off, costs off) select * from sparse where value = 1;
 
 
 -- Long column names.
@@ -70,5 +70,5 @@ from generate_series(1, 63) x
 select count(compress_chunk(x)) from show_chunks('sparse') x;
 vacuum analyze sparse;
 
-explain (costs off) select * from sparse where Abcdef012345678_Bbcdef012345678_Cbcdef012345678_Dbcdef0 = 1;
+explain (buffers off, costs off) select * from sparse where Abcdef012345678_Bbcdef012345678_Cbcdef012345678_Dbcdef0 = 1;
 
