@@ -351,10 +351,10 @@ RESET enable_seqscan;
 RESET enable_bitmapscan;
 
 -- Test chunk merging with default compression settings
-CREATE TABLE test_defaults ("Time" timestamptz, i integer, value integer);
-SELECT table_name from create_hypertable('test_defaults', 'Time', chunk_time_interval=> INTERVAL '1 hour');
+CREATE TABLE test_defaults ("Time" timestamptz, i integer, value integer) WITH (tsdb.hypertable, tsdb.chunk_interval='1 hour');
 CREATE INDEX ON test_defaults (i);
 ALTER TABLE test_defaults set (timescaledb.compress, timescaledb.compress_chunk_time_interval='2 hours');
+SELECT delete_job(1000);
 
 -- This will generate 24 chunks
 INSERT INTO test_defaults
