@@ -7,7 +7,7 @@
 -- which is removed in latest schema revision
 \c :TEST_DBNAME :ROLE_CLUSTER_SUPERUSER
 SET ROLE :ROLE_DEFAULT_PERM_USER;
-\set EXPLAIN 'EXPLAIN (VERBOSE, COSTS OFF)'
+\set EXPLAIN 'EXPLAIN (VERBOSE, BUFFERS OFF, COSTS OFF)'
 
 CREATE TABLE hyper(
     time INT NOT NULL,
