@@ -412,7 +412,6 @@ SELECT * FROM conditions_large_1y1m ORDER BY bucket;
 
 -- Trigger merged refresh to check corresponding code path as well
 DROP MATERIALIZED VIEW conditions_large_1y;
-SET timescaledb.materializations_per_refresh_window = 0;
 
 SET timescaledb.debug_allow_cagg_with_deprecated_funcs = true;
 CREATE MATERIALIZED VIEW conditions_large_1y
@@ -435,8 +434,6 @@ CALL refresh_continuous_aggregate('conditions_large_1y', '2020-01-01', '2021-01-
 
 SELECT * FROM conditions_large_1y ORDER BY bucket;
 
-RESET timescaledb.materializations_per_refresh_window;
-
 -- Test the specific code path of creating a CAGG on top of empty hypertable.
 
 CREATE TABLE conditions_empty(
