@@ -4,13 +4,9 @@
 
 -- Setup some variables
 SELECT
-    format('\! zcat < include/data/cagg_migrate_%1$s.sql.gz > %2$s/results/cagg_migrate_%1$s.sql', lower(:'TIME_DIMENSION_DATATYPE'), :'TEST_OUTPUT_DIR') AS "ZCAT_CMD",
-    format('%2$s/results/cagg_migrate_%1$s.sql', lower(:'TIME_DIMENSION_DATATYPE'), :'TEST_OUTPUT_DIR') AS "TEST_SCHEMA_FILE"
+    format('../data/cagg_migrate_%1$s.sql', lower(:'TIME_DIMENSION_DATATYPE')) AS "TEST_SCHEMA_FILE"
 \gset
 
--- decompress dump file
-:ZCAT_CMD
-
 -- restore dump
 SELECT timescaledb_pre_restore();
 \ir :TEST_SCHEMA_FILE
